@@ -1,7 +1,7 @@
 use crate::state::State;
 use crate::{Initiator, Responder, XXVault};
-use ockam_core::{async_trait, compat::boxed::Box};
-use ockam_core::{AsyncTryClone, Result};
+use ockam_core::{async_trait, compat::boxed::Box, AsyncTryClone, Result};
+
 use ockam_key_exchange_core::NewKeyExchanger;
 
 /// Represents an XX NewKeyExchanger
@@ -21,6 +21,7 @@ impl<V: XXVault> XXNewKeyExchanger<V> {
 impl<V: XXVault> NewKeyExchanger for XXNewKeyExchanger<V> {
     type Initiator = Initiator<V>;
     type Responder = Responder<V>;
+
     /// Create a new initiator using the provided backing vault
     async fn initiator(&self) -> Result<Initiator<V>> {
         let ss = State::new(&self.vault).await?;
